@@ -23,7 +23,6 @@ import warnings
 import zlib
 from collections import defaultdict
 from functools import partial
-from io import StringIO
 from random import Random
 from typing import (
     TYPE_CHECKING,
@@ -76,10 +75,11 @@ from hypothesis.internal.compat import (
     int_from_bytes,
 )
 from hypothesis.internal.conjecture.data import ConjectureData, Status
-from hypothesis.internal.conjecture.engine import ConjectureRunner
+from hypothesis.internal.conjecture.engine import BUFFER_SIZE, ConjectureRunner
 from hypothesis.internal.conjecture.shrinker import sort_key
 from hypothesis.internal.entropy import deterministic_PRNG
 from hypothesis.internal.escalation import (
+    current_pytest_item,
     escalate_hypothesis_internal_error,
     format_exception,
     get_interesting_origin,
@@ -107,12 +107,11 @@ from hypothesis.reporting import (
     with_reporter,
 )
 from hypothesis.statistics import describe_targets, note_statistics
-from hypothesis.strategies._internal.collections import TupleStrategy
 from hypothesis.strategies._internal.misc import NOTHING
 from hypothesis.strategies._internal.strategies import (
     Ex,
-    MappedSearchStrategy,
     SearchStrategy,
+    check_strategy,
 )
 from hypothesis.vendor.pretty import RepresentationPrinter
 from hypothesis.version import __version__
@@ -341,20 +340,6 @@ def decode_failure(blob):
         )
 
 
-class WithRunner(MappedSearchStrategy):
-    def __init__(self, base, runner):
-        assert runner is not None
-        super().__init__(base)
-        self.runner = runner
-
-    def do_draw(self, data):
-        data.hypothesis_runner = self.runner
-        return self.mapped_strategy.do_draw(data)
-
-    def __repr__(self):
-        return f"WithRunner({self.mapped_strategy!r}, runner={self.runner!r})"
-
-
 def _invalid(message, *, exc=InvalidArgument, test, given_kwargs):
     @impersonate(test)
     def wrapped_test(*arguments, **kwargs):  # pragma: no cover  # coverage limitation
@@ -431,32 +416,8 @@ def is_invalid_test(test, original_sig, given_arguments, given_kwargs):
         )
 
 
-class ArtificialDataForExample(ConjectureData):
-    """Dummy object that pretends to be a ConjectureData object for the purposes of
-    drawing arguments for @example. Provides just enough of the ConjectureData API
-    to allow the test to run. Does not support any sort of interactive drawing,
-    but that's fine because you can't access that when all of your arguments are
-    provided by @example.
-    """
-
-    def __init__(self, args, kwargs):
-        self.__draws = 0
-        self.__args = args
-        self.__kwargs = kwargs
-        super().__init__(max_length=0, prefix=b"", random=None)
-
-    def draw_bits(self, n):
-        raise NotImplementedError("Dummy object should never be asked for bits.")
-
-    def draw(self, strategy):
-        assert self.__draws == 0
-        self.__draws += 1
-        # The main strategy for given is always a tuples strategy that returns
-        # first positional arguments then keyword arguments.
-        return self.__args, self.__kwargs
-
-
 def execute_explicit_examples(state, wrapped_test, arguments, kwargs, original_sig):
+    assert isinstance(state, StateForActualGivenExecution)
     posargs = [
         p.name
         for p in original_sig.parameters.values()
@@ -506,17 +467,23 @@ def execute_explicit_examples(state, wrapped_test, arguments, kwargs, original_s
         with local_settings(state.settings):
             fragments_reported = []
             try:
-                adata = ArtificialDataForExample(arguments, example_kwargs)
                 bits = ", ".join(nicerepr(x) for x in arguments) + ", ".join(
                     f"{k}={nicerepr(v)}" for k, v in example_kwargs.items()
                 )
+                execute_example = partial(
+                    state.execute_once,
+                    ConjectureData.for_buffer(b""),
+                    is_final=True,
+                    print_example=True,
+                    example_kwargs=example_kwargs,
+                )
                 with with_reporter(fragments_reported.append):
                     if example.raises is None:
-                        state.execute_once(adata, is_final=True, print_example=True)
+                        execute_example()
                     else:
                         # @example(...).xfail(...)
                         try:
-                            state.execute_once(adata, is_final=True, print_example=True)
+                            execute_example()
                         except failure_exceptions_to_catch() as err:
                             if not isinstance(err, example.raises):
                                 raise
@@ -617,6 +584,14 @@ def get_random_for_wrapped_test(test, wrapped_test):
         return Random(seed)
 
 
+@attr.s
+class Stuff:
+    selfy = attr.ib(default=None)
+    args = attr.ib(factory=tuple)
+    kwargs = attr.ib(factory=dict)
+    given_kwargs = attr.ib(factory=dict)
+
+
 def process_arguments_to_given(wrapped_test, arguments, kwargs, given_kwargs, params):
     selfy = None
     arguments, kwargs = convert_positional_arguments(wrapped_test, arguments, kwargs)
@@ -639,22 +614,13 @@ def process_arguments_to_given(wrapped_test, arguments, kwargs, given_kwargs, pa
 
     arguments = tuple(arguments)
 
-    # We use TupleStrategy over tuples() here to avoid polluting
-    # st.STRATEGY_CACHE with references (see #493), and because this is
-    # trivial anyway if the fixed_dictionaries strategy is cacheable.
-    search_strategy = TupleStrategy(
-        (
-            st.just(arguments),
-            st.fixed_dictionaries(given_kwargs).map(lambda args: dict(args, **kwargs)),
-        )
-    )
+    for k, s in given_kwargs.items():
+        check_strategy(s, name=k)
+        s.validate()
 
-    if selfy is not None:
-        search_strategy = WithRunner(search_strategy, selfy)
+    stuff = Stuff(selfy=selfy, args=arguments, kwargs=kwargs, given_kwargs=given_kwargs)
 
-    search_strategy.validate()
-
-    return arguments, kwargs, test_runner, search_strategy
+    return arguments, kwargs, test_runner, stuff
 
 
 def skip_exceptions_to_reraise():
@@ -713,11 +679,9 @@ def new_given_signature(original_sig, given_kwargs):
 
 
 class StateForActualGivenExecution:
-    def __init__(
-        self, test_runner, search_strategy, test, settings, random, wrapped_test
-    ):
+    def __init__(self, test_runner, stuff, test, settings, random, wrapped_test):
         self.test_runner = test_runner
-        self.search_strategy = search_strategy
+        self.stuff = stuff
         self.settings = settings
         self.last_exception = None
         self.falsifying_examples = ()
@@ -741,7 +705,12 @@ class StateForActualGivenExecution:
         self.explain_traces = defaultdict(set)
 
     def execute_once(
-        self, data, print_example=False, is_final=False, expected_failure=None
+        self,
+        data,
+        print_example=False,
+        is_final=False,
+        expected_failure=None,
+        example_kwargs=None,
     ):
         """Run the test function once, using ``data`` as input.
 
@@ -786,16 +755,26 @@ class StateForActualGivenExecution:
             with local_settings(self.settings):
                 with deterministic_PRNG():
                     with BuildContext(data, is_final=is_final) as context:
+                        if self.stuff.selfy is not None:
+                            data.hypothesis_runner = self.stuff.selfy
                         # Generate all arguments to the test function.
-                        args, kwargs = data.draw(self.search_strategy)
+                        args = self.stuff.args
+                        kwargs = dict(self.stuff.kwargs)
+                        if example_kwargs is None:
+                            a, kw, argslices = context.prep_args_kwargs_from_strategies(
+                                (), self.stuff.given_kwargs
+                            )
+                            assert not a, "strategies all moved to kwargs by now"
+                        else:
+                            kw = example_kwargs
+                            argslices = {}
+                        kwargs.update(kw)
                         if expected_failure is not None:
                             nonlocal text_repr
                             text_repr = repr_call(test, args, kwargs)
 
                         if print_example or current_verbosity() >= Verbosity.verbose:
-                            output = StringIO()
-
-                            printer = RepresentationPrinter(output, context=context)
+                            printer = RepresentationPrinter(context=context)
                             if print_example:
                                 printer.text("Falsifying example:")
                             else:
@@ -808,6 +787,12 @@ class StateForActualGivenExecution:
                                     args,
                                     kwargs,
                                     force_split=True,
+                                    arg_slices=argslices,
+                                    leading_comment=(
+                                        "# " + context.data.slice_comments[(0, 0)]
+                                        if (0, 0) in context.data.slice_comments
+                                        else None
+                                    ),
                                 )
                             report(printer.getvalue())
                         return test(*args, **kwargs)
@@ -989,6 +974,7 @@ class StateForActualGivenExecution:
             fragments = []
 
             ran_example = ConjectureData.for_buffer(falsifying_example.buffer)
+            ran_example.slice_comments = falsifying_example.slice_comments
             assert info.__expected_exception is not None
             try:
                 with with_reporter(fragments.append):
@@ -1045,10 +1031,15 @@ def add_note(exc, note):
 
 def _raise_to_user(errors_to_report, settings, target_lines, trailer=""):
     """Helper function for attaching notes and grouping multiple errors."""
-    if settings.verbosity >= Verbosity.normal:
-        for fragments, err in errors_to_report:
-            for note in fragments:
-                add_note(err, note)
+    failing_prefix = "Falsifying example: "
+    ls = []
+    for fragments, err in errors_to_report:
+        for note in fragments:
+            add_note(err, note)
+            if note.startswith(failing_prefix):
+                ls.append(note[len(failing_prefix) :])
+    if current_pytest_item.value:
+        current_pytest_item.value._hypothesis_failing_examples = ls
 
     if len(errors_to_report) == 1:
         _, the_error_hypothesis_found = errors_to_report[0]
@@ -1234,7 +1225,7 @@ def given(
             processed_args = process_arguments_to_given(
                 wrapped_test, arguments, kwargs, given_kwargs, new_signature.parameters
             )
-            arguments, kwargs, test_runner, search_strategy = processed_args
+            arguments, kwargs, test_runner, stuff = processed_args
 
             if (
                 inspect.iscoroutinefunction(test)
@@ -1252,8 +1243,8 @@ def given(
                     "readthedocs.io/en/latest/details.html#custom-function-execution"
                 )
 
-            runner = getattr(search_strategy, "runner", None)
-            if isinstance(runner, TestCase) and test.__name__ in dir(TestCase):
+            runner = stuff.selfy
+            if isinstance(stuff.selfy, TestCase) and test.__name__ in dir(TestCase):
                 msg = (
                     f"You have applied @given to the method {test.__name__}, which is "
                     "used by the unittest runner but is not itself a test."
@@ -1272,7 +1263,7 @@ def given(
                 )
 
             state = StateForActualGivenExecution(
-                test_runner, search_strategy, test, settings, random, wrapped_test
+                test_runner, stuff, test, settings, random, wrapped_test
             )
 
             reproduce_failure = wrapped_test._hypothesis_internal_use_reproduce_failure
@@ -1415,13 +1406,13 @@ def given(
                 parent=wrapped_test._hypothesis_internal_use_settings, deadline=None
             )
             random = get_random_for_wrapped_test(test, wrapped_test)
-            _args, _kwargs, test_runner, search_strategy = process_arguments_to_given(
+            _args, _kwargs, test_runner, stuff = process_arguments_to_given(
                 wrapped_test, (), {}, given_kwargs, new_signature.parameters
             )
             assert not _args
             assert not _kwargs
             state = StateForActualGivenExecution(
-                test_runner, search_strategy, test, settings, random, wrapped_test
+                test_runner, stuff, test, settings, random, wrapped_test
             )
             digest = function_digest(test)
             # We track the minimal-so-far example for each distinct origin, so
@@ -1436,7 +1427,7 @@ def given(
                 # This inner part is all that the fuzzer will actually run,
                 # so we keep it as small and as fast as possible.
                 if isinstance(buffer, io.IOBase):
-                    buffer = buffer.read()
+                    buffer = buffer.read(BUFFER_SIZE)
                 assert isinstance(buffer, (bytes, bytearray, memoryview))
                 data = ConjectureData.for_buffer(buffer)
                 try:
