@@ -400,10 +400,10 @@ class Examples:
         return self.starts_and_ends[1]
 
     class _discarded(ExampleProperty):
-        def begin(self):
-            self.result: "Set[int]" = set()
+        def begin(self) -> None:
+            self.result: "Set[int]" = set()  # type: ignore  # IntList in parent class
 
-        def finish(self):
+        def finish(self) -> FrozenSet[int]:
             return frozenset(self.result)
 
         def stop_example(self, i: int, discarded: bool) -> None:
@@ -413,9 +413,9 @@ class Examples:
     discarded: FrozenSet[int] = calculated_example_property(_discarded)
 
     class _trivial(ExampleProperty):
-        def begin(self):
+        def begin(self) -> None:
             self.nontrivial = IntList.of_length(len(self.examples))
-            self.result: "Set[int]" = set()
+            self.result: "Set[int]" = set()  # type: ignore  # IntList in parent class
 
         def block(self, i: int) -> None:
             if not self.examples.blocks.trivial(i):
@@ -428,7 +428,7 @@ class Examples:
             else:
                 self.result.add(i)
 
-        def finish(self):
+        def finish(self) -> FrozenSet[int]:
             return frozenset(self.result)
 
     trivial: FrozenSet[int] = calculated_example_property(_trivial)
@@ -456,7 +456,7 @@ class Examples:
     label_indices: IntList = calculated_example_property(_label_indices)
 
     class _mutator_groups(ExampleProperty):
-        def begin(self):
+        def begin(self) -> None:
             self.groups: "Dict[Tuple[int, int], List[int]]" = defaultdict(list)
 
         def start_example(self, i: int, label_index: int) -> None:
@@ -776,6 +776,8 @@ class ConjectureResult:
     tags: FrozenSet[StructuralCoverageTag] = attr.ib()
     forced_indices: FrozenSet[int] = attr.ib(repr=False)
     examples: Examples = attr.ib(repr=False)
+    arg_slices: Set[Tuple[int, int]] = attr.ib(repr=False)
+    slice_comments: Dict[Tuple[int, int], str] = attr.ib(repr=False)
 
     index: int = attr.ib(init=False)
 
@@ -860,6 +862,11 @@ class ConjectureData:
         self.depth = -1
         self.__example_record = ExampleRecord()
 
+        # Slice indices for discrete reportable parts that which-parts-matter can
+        # try varying, to report if the minimal example always fails anyway.
+        self.arg_slices: Set[Tuple[int, int]] = set()
+        self.slice_comments: Dict[Tuple[int, int], str] = {}
+
         self.extra_information = ExtraInformation()
 
         self.start_example(TOP_LABEL)
@@ -893,6 +900,8 @@ class ConjectureData:
                 target_observations=self.target_observations,
                 tags=frozenset(self.tags),
                 forced_indices=frozenset(self.forced_indices),
+                arg_slices=self.arg_slices,
+                slice_comments=self.slice_comments,
             )
             assert self.__result is not None
             self.blocks.transfer_ownership(self.__result)
