@@ -401,7 +401,7 @@ def floats(
 
     The width argument specifies the maximum number of bits of precision
     required to represent the generated float. Valid values are 16, 32, or 64.
-    Passing ``width=32`` will still use the builtin 64-bit ``float`` class,
+    Passing ``width=32`` will still use the builtin 64-bit :class:`~python:float` class,
     but always for values which can be exactly represented as a 32-bit float.
 
     The exclude_min and exclude_max argument can be used to generate numbers
@@ -438,7 +438,7 @@ def floats(
 
     if math.copysign(1.0, -0.0) == 1.0:  # pragma: no cover
         raise FloatingPointError(
-            "You Python install can't represent -0.0, which is required by the "
+            "Your Python install can't represent -0.0, which is required by the "
             "IEEE-754 floating-point specification.  This is probably because it was "
             "compiled with an unsafe option like -ffast-math; for a more detailed "
             "explanation see https://simonbyrne.github.io/notes/fastmath/"
