@@ -329,7 +329,7 @@ class SearchStrategy(Generic[Ex]):
             deadline=None,
             verbosity=Verbosity.quiet,
             phases=(Phase.generate,),
-            suppress_health_check=HealthCheck.all(),
+            suppress_health_check=list(HealthCheck),
         )
         def example_generating_inner_function(ex):
             self.__examples.append(ex)
@@ -832,16 +832,15 @@ class MappedSearchStrategy(SearchStrategy[Ex]):
             ):
                 warnings.simplefilter("ignore", BytesWarning)
             for _ in range(3):
-                i = data.index
                 try:
                     data.start_example(MAPPED_SEARCH_STRATEGY_DO_DRAW_LABEL)
-                    result = self.pack(data.draw(self.mapped_strategy))  # type: ignore
+                    x = data.draw(self.mapped_strategy)
+                    result = self.pack(x)  # type: ignore
                     data.stop_example()
+                    _current_build_context.value.record_call(result, self.pack, [x], {})
                     return result
                 except UnsatisfiedAssumption:
                     data.stop_example(discard=True)
-                    if data.index == i:
-                        raise
         raise UnsatisfiedAssumption()
 
     @property
