@@ -28,7 +28,12 @@ from types import FunctionType
 
 from hypothesis import strategies as st
 from hypothesis.errors import InvalidArgument, ResolutionFailed
-from hypothesis.internal.compat import PYPY, BaseExceptionGroup, ExceptionGroup
+from hypothesis.internal.compat import (
+    PYPY,
+    BaseExceptionGroup,
+    ExceptionGroup,
+    get_origin,
+)
 from hypothesis.internal.conjecture.utils import many as conjecture_utils_many
 from hypothesis.strategies._internal.datetime import zoneinfo  # type: ignore
 from hypothesis.strategies._internal.ipaddress import (
@@ -423,7 +428,7 @@ def from_typing_type(thing):
         else:
             union_elems = ()
         if not any(
-            isinstance(T, type) and issubclass(int, T)
+            isinstance(T, type) and issubclass(int, get_origin(T) or T)
             for T in list(union_elems) + [elem_type]
         ):
             mapping.pop(typing.ByteString, None)
@@ -582,7 +587,7 @@ if PYPY:
 _global_type_lookup[type] = st.sampled_from(
     [type(None)] + sorted(_global_type_lookup, key=str)
 )
-if sys.version_info[:2] >= (3, 9):  # pragma: no cover
+if sys.version_info[:2] >= (3, 9):
     # subclass of MutableMapping, and in Python 3.9 we resolve to a union
     # which includes this... but we don't actually ever want to build one.
     _global_type_lookup[os._Environ] = st.just(os.environ)
